@@ -261,11 +261,17 @@ int Pty::start(const QString& programName,
 void Pty::setWriteable(bool writeable)
 {
     KDE_struct_stat sbuf;
-    KDE::stat(pty()->ttyName(), &sbuf);
-    if (writeable)
-        KDE::chmod(pty()->ttyName(), sbuf.st_mode | S_IWGRP);
-    else
-        KDE::chmod(pty()->ttyName(), sbuf.st_mode & ~(S_IWGRP | S_IWOTH));
+    if (KDE::stat(pty()->ttyName(), &sbuf) == 0) {
+        if (writeable) {
+            if (KDE::chmod(pty()->ttyName(), sbuf.st_mode | S_IWGRP) < 0) {
+                kWarning() << "Could not set writeable on "<<pty()->ttyName();
+            }
+        } else {
+            if (KDE::chmod(pty()->ttyName(), sbuf.st_mode & ~(S_IWGRP | S_IWOTH)) < 0) {
+                kWarning() << "Could not unset writeable on "<<pty()->ttyName();
+            }
+        }
+    }
 }
 
 void Pty::closePty()
